@@ -84,7 +84,7 @@ class AioIOWrapper(object):
         self.stdout.write('EOF')
 
     def check_coroutine(self, fn):
-        if hasattr(fn, '__wrapped__') and getattr(fn.__wrapped__, 'is_coroutine'):
+        if hasattr(fn, '__wrapped__') and getattr(fn.__wrapped__, 'is_coroutine', None):
             self.is_coroutine = True
         else:
             self.is_coroutine = False
